package com.ynet.life.sujrb.base;

import com.ynet.gene.component.factory.ComponentFactory;
import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.IndexedCollection;
import com.ynet.life.base.LifeDBAccess;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.sujrb.vipclient.PBTaskGroup;
import com.ynet.life.sujrb.vipclient.PBTaskInfo;
import com.ynet.life.sujrb.vipclient.PBTaskInfoParser;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;

/* loaded from: com_ynet_life_sujrb_base.jar:com/ynet/life/sujrb/base/PBMenuTree.class */
public class PBMenuTree {
    private static final String COMPONENT_FACTORY_NAME = "taskInfo";
    private static final String TASK_FILE_LOCATION = "/WEB-INF/mvcs/sujrb/";
    private static String[] TASK_GROUP_NAME = {"taskInfo.tsk"};
    private static Map TASK_GROUP_MAP = new HashMap();
    private static final String SQL_USER_BSN = "SELECT BDF_BSNCODE FROM fsp_bsndef";
    private static final String SQL_USER_BSN_PB = "SELECT BDF_BSNCODE,BDF_NAME,BDF_DESC,BDF_BSNLVL,BDF_STT,BDF_ISQUICKMENU FROM fsp_bsndef where BDF_STT='0' AND BDF_BSNCODE in(select RSR_BSNCODE from fsp_role_bsn_rel where RSR_ROLEID=? AND RSR_STT='0')";

    private PBMenuTree() {
    }

    public static void initialize(String rootPath) throws TranFailException {
        ComponentFactory factory = new ComponentFactory();
        PBTaskInfoParser parser = new PBTaskInfoParser();
        factory.setComponentParser(parser);
        parser.setComponentFactory(factory);
        int size = TASK_GROUP_NAME.length;
        for (int i = 0; i < size; i++) {
            String groupName = TASK_GROUP_NAME[i];
            factory.initializeComponentFactory(COMPONENT_FACTORY_NAME, String.valueOf(rootPath) + TASK_FILE_LOCATION + groupName);
            try {
                PBTaskGroup rootTaskGroup = (PBTaskGroup) factory.getRootComponent();
                TASK_GROUP_MAP.put(groupName, rootTaskGroup);
                Map menuTable = new HashMap();
                Map menuRef = new HashMap();
                for (PBTaskInfo element : getAllTaskInfo(rootTaskGroup)) {
                    menuTable.put(element.getId(), element);
                    menuRef.put(element.getAction(), element.getId());
                }
                PBStandard.initializeMenuTable(menuTable, menuRef);
            } catch (Exception ex) {
                Trace.logError("LifeAction", "解析菜单文件异常", ex);
                throw new TranFailException(ex);
            }
        }
    }

    public static List getAllUserTaskInfo(Context sessionContext, String taskGroupName) {
        Set userBusinessHashSet = getAllUserTaskHash(sessionContext);
        return getUserTaskInfo(sessionContext, taskGroupName, userBusinessHashSet);
    }

    public static Set getAllUserTaskHash(Context sessionCtx) {
        Connection connection = null;
        Set businessCodeSet = new HashSet();
        try {
            try {
                String logonType = (String) sessionCtx.get(PBConstants.FIELD_LOGON_TYPE);
                List inputList = new ArrayList();
                String roleType = "00";
                if (PBConstants.SAFE_PASSWORD_AND_DYNAMIC_CODE.equals(logonType)) {
                    roleType = "01";
                }
                inputList.add(roleType);
                Connection connection2 = LifeDBAccess.getConnection();
                connection = connection2;
                Iterator iterator = LifeDBAccess.queryMultipleResult(connection2, SQL_USER_BSN, inputList, 1).iterator();
                while (iterator.hasNext()) {
                    String businessCode = (String) ((List) iterator.next()).get(0);
                    if (businessCode != null) {
                        businessCodeSet.add(businessCode);
                    }
                }
                try {
                    LifeDBAccess.releaseConnection(connection);
                } catch (TranFailException te) {
                    Trace.logError("LifeJDBC", "JDBC异常", te);
                }
            } catch (TranFailException unused) {
                if (connection != null) {
                    try {
                        connection.rollback();
                    } catch (SQLException e) {
                        Trace.logError("LifeJDBC", "JDBC异常", e);
                    }
                }
                try {
                    LifeDBAccess.releaseConnection(connection);
                } catch (TranFailException te2) {
                    Trace.logError("LifeJDBC", "JDBC异常", te2);
                }
            }
            return businessCodeSet;
        } catch (Throwable th) {
            try {
                LifeDBAccess.releaseConnection(connection);
            } catch (TranFailException te3) {
                Trace.logError("LifeJDBC", "JDBC异常", te3);
            }
            throw th;
        }
    }

    public static List getUserTaskInfo(Context sessionContext, String taskGroupName, String roleId) {
        Set userBusinessHashSet = getUserTaskHash(sessionContext, roleId);
        return getUserTaskInfo(sessionContext, taskGroupName, userBusinessHashSet);
    }

    public static List getUserTaskInfo(Context sessionContext, String taskGroupName, Set userBusinessHashSet) {
        PBTaskGroup rootTaskGroup = (PBTaskGroup) TASK_GROUP_MAP.get(taskGroupName);
        if (rootTaskGroup == null) {
            return null;
        }
        try {
            PBTaskGroup userTaskGroup = new PBTaskGroup();
            if ("1".equals(LifeStandard.getSystemParam("PB_MENU_SHOW_TYPE"))) {
                buildUserMenuTree(rootTaskGroup, userTaskGroup, null, "ZH_CN");
            } else {
                buildUserMenuTree(rootTaskGroup, userTaskGroup, userBusinessHashSet, "ZH_CN");
            }
            List resultList = userTaskGroup.getChilds();
            return resultList;
        } catch (TranFailException ex) {
            Trace.logError("LifeAction", "获取用户菜单失败", ex);
            return null;
        }
    }

    private static PBTaskGroup buildQuickMenu(Context sessionContext, String language) {
        PBTaskGroup result = new PBTaskGroup();
        result.setName(LifeStandard.getResouceDisplayAt("我的网银", language));
        result.setDftTaskId("showWelcome.do");
        try {
            IndexedCollection iColl = sessionContext.getDataElement(PBConstants.FIELD_ICOLL_QUICK_MENU);
            int iCollSize = iColl.size();
            for (int i = 0; i < iCollSize; i++) {
                PBTaskInfo businessInfo = PBStandard.getTaskInfo((String) iColl.getElementAt(i).getDataValue(PBConstants.FIELD_BUSINESS_CODE));
                PBTaskInfo task = new PBTaskInfo();
                task.setId(businessInfo.getId());
                task.setAction(businessInfo.getAction());
                task.setCatalog(businessInfo.getCatalog());
                task.setName(LifeStandard.getResouceDisplayAt(businessInfo.getName(), language));
                result.addTaskInfo(task);
            }
        } catch (GENEException ex) {
            Trace.logError("LifeAction", "获取快捷菜单失败", ex);
        }
        return result;
    }

    private static List getAllTaskInfo(PBTaskGroup PBTaskGroup) {
        List result = new ArrayList();
        List childs = PBTaskGroup.getChilds();
        int size = childs.size();
        if (childs.size() == 0) {
            return result;
        }
        for (int i = 0; i < size; i++) {
            Object element = childs.get(i);
            if (element instanceof PBTaskGroup) {
                result.addAll(getAllTaskInfo((PBTaskGroup) element));
            } else if (element instanceof PBTaskInfo) {
                result.add(element);
            }
        }
        return result;
    }

    private static void buildUserMenuTree(PBTaskGroup defaultTaskTree, PBTaskGroup userTaskTree, Set userBusinessHashSet, String language) throws TranFailException {
        if (defaultTaskTree == null) {
            return;
        }
        userTaskTree.setId(defaultTaskTree.getId());
        userTaskTree.setName(LifeStandard.getResouceDisplayAt(defaultTaskTree.getName(), language));
        userTaskTree.setDftTaskId(defaultTaskTree.getDftTaskId());
        List childs = defaultTaskTree.getChilds();
        int size = childs.size();
        if (childs.size() == 0) {
            return;
        }
        for (int i = 0; i < size; i++) {
            Object element = childs.get(i);
            if (element instanceof PBTaskGroup) {
                PBTaskGroup PBTaskGroup = (PBTaskGroup) element;
                PBTaskGroup userSubTaskTree = new PBTaskGroup();
                buildUserMenuTree(PBTaskGroup, userSubTaskTree, userBusinessHashSet, language);
                if (userSubTaskTree.getChilds() != null && userSubTaskTree.getChilds().size() > 0) {
                    userSubTaskTree.setParent(userTaskTree);
                    userSubTaskTree.setCatalog(PBTaskGroup.getCatalog());
                    userSubTaskTree.setAction(PBTaskGroup.getAction());
                    userTaskTree.addTaskGroup(userSubTaskTree);
                }
            } else if (element instanceof PBTaskInfo) {
                PBTaskInfo PBTaskInfo = (PBTaskInfo) element;
                if (PBTaskInfo.getAction() == null || PBTaskInfo.getId() == null) {
                    System.out.println(PBTaskInfo.getId());
                }
                if (userHasMenu(userBusinessHashSet, PBTaskInfo.getAction())) {
                    PBTaskInfo newTaskInfo = new PBTaskInfo();
                    newTaskInfo.setId(PBTaskInfo.getId());
                    newTaskInfo.setName(LifeStandard.getResouceDisplayAt(PBTaskInfo.getName(), language));
                    newTaskInfo.setAction(PBTaskInfo.getAction());
                    newTaskInfo.setParent(userTaskTree);
                    newTaskInfo.setCatalog(PBTaskInfo.getCatalog());
                    userTaskTree.addTaskInfo(newTaskInfo);
                }
            }
        }
    }

    private static Set getUserTaskHash(Context sessionContext, String roleId) {
        Connection connection = null;
        try {
            try {
                try {
                    List inputList = new ArrayList();
                    inputList.add(roleId);
                    Connection connection2 = LifeDBAccess.getConnection();
                    connection = connection2;
                    Map userBusinessHash = getUserBusinessHash(LifeDBAccess.queryMultipleResult(connection2, SQL_USER_BSN_PB, inputList, 1));
                    LifeDBAccess.releaseConnection(connection);
                    return userBusinessHash.keySet();
                } catch (TranFailException e) {
                    if (connection != null) {
                        try {
                            connection.rollback();
                        } catch (SQLException e2) {
                            Trace.logError("LifeJDBC", "JDBC异常", e2);
                            throw new GENEException(e2);
                        }
                    }
                    throw e;
                }
            } catch (Throwable th) {
                LifeDBAccess.releaseConnection((Connection) null);
                throw th;
            }
        } catch (GENEException ex) {
            Trace.logError("LifeAction", "获取用户交易列表错误", ex);
            return new HashSet();
        }
    }

    private static Map getUserBusinessHash(List list) {
        HashMap businessHash = new HashMap();
        Iterator iterator = list.iterator();
        while (iterator.hasNext()) {
            String businessCode = (String) ((List) iterator.next()).get(0);
            if (businessCode != null) {
                businessHash.put(businessCode, 0);
            }
        }
        return businessHash;
    }

    private static boolean userHasMenu(Set userBusinessHashSet, String action) throws TranFailException {
        if (userBusinessHashSet == null) {
            return true;
        }
        String businessCode = PBStandard.getActionBusinessCode(action);
        if (businessCode == null) {
            Trace.logWarning("LifeAction", "EBLN0000未定义菜单代码" + action + "所关联的交易代码");
            throw new TranFailException("EBLN0000", "未定义菜单代码" + action + "所关联的交易代码", false);
        }
        return userBusinessHashSet.contains(businessCode);
    }
}
